# Changelog

## [Unreleased]

## [0.3.0] - 2025-04-08

* Fix error when using both `*` and `!=` operators.

## [0.2.0] - 2024-11-27

* Fix entrypoint name for the package

## [0.1.0] - 2024-11-27

* Add support for buil-in keywords
* Add support for buil-in functions
* Add support for buil-in operators
* Add support for regex expressions
